Software Heritage - Code Scanner resources
==========================================

The purpose of the `resources` directory is to store various static resources used by the scanner.

gitignore
---------

The `gitignore` directory list a vast collection of gitignore files that can be used with the
scanner.
The directory is a checkout from https://github.com/github/gitignore and should be updated to get
ignore definition for new languages and framework.

